@@ -48,7 +48,7 @@ typedef struct bauth_chain {
 
 
 // buffer pour les cookies et authentification
-typedef struct {
+typedef struct t_cookie {
   int max_len;
   char data[32768];
   bauth_chain auth;
