@@ -50,8 +50,10 @@ typedef char* (* t_hts_htmlcheck_query2)(char* question);
 typedef char* (* t_hts_htmlcheck_query3)(char* question);
 typedef int   (* t_hts_htmlcheck_loop)(lien_back* back,int back_max,int back_index,int lien_tot,int lien_ntot,int stat_time,hts_stat_struct* stats);
 typedef int   (* t_hts_htmlcheck_check)(char* adr,char* fil,int status);
+typedef int   (* t_hts_htmlcheck_check_mime)(char* adr,char* fil,char* mime,int status);
 typedef void  (* t_hts_htmlcheck_pause)(char* lockfile);
 typedef void  (* t_hts_htmlcheck_filesave)(char* file);
+typedef void  (* t_hts_htmlcheck_filesave2)(char* hostname,char* filename,char* localfile,int is_new,int is_modified,int not_updated);
 typedef int   (* t_hts_htmlcheck_linkdetected)(char* link);
 typedef int   (* t_hts_htmlcheck_linkdetected2)(char* link, char* tag_start);
 typedef int   (* t_hts_htmlcheck_xfrstatus)(lien_back* back);
@@ -77,8 +79,10 @@ extern t_hts_htmlcheck_query2     hts_htmlcheck_query2;
 extern t_hts_htmlcheck_query3     hts_htmlcheck_query3;
 extern t_hts_htmlcheck_loop       hts_htmlcheck_loop;
 extern t_hts_htmlcheck_check      hts_htmlcheck_check;
+extern t_hts_htmlcheck_check_mime hts_htmlcheck_check_mime;
 extern t_hts_htmlcheck_pause      hts_htmlcheck_pause;
 extern t_hts_htmlcheck_filesave   hts_htmlcheck_filesave;
+extern t_hts_htmlcheck_filesave2  hts_htmlcheck_filesave2;
 extern t_hts_htmlcheck_linkdetected hts_htmlcheck_linkdetected;
 extern t_hts_htmlcheck_linkdetected2 hts_htmlcheck_linkdetected2;
 extern t_hts_htmlcheck_xfrstatus  hts_htmlcheck_xfrstatus;
