@@ -49,7 +49,7 @@ Please visit our Website: http://www.httrack.com
 #ifdef HTS_INTERNAL_BYTECODE
 #if USE_BEGINTHREAD
 void launch_ftp(lien_back* back);
-PTHREAD_TYPE back_launch_ftp( void* pP );
+PTHREAD_TYPE PTHREAD_TYPE_FNC back_launch_ftp( void* pP );
 #else
 void launch_ftp(lien_back* back,char* path,char* exec);
 int back_launch_ftp(lien_back* back);
