@@ -185,7 +185,7 @@ int hts_parse_java(htsmoduleStruct* str)
           if((tab[i].index1!=SClass) && (tab[i].index1!=Class) && (tab[tab[i].index1].name[0]!='[')) {
             
             if(!strstr(tab[tab[i].index1].name,"java/")) {
-              char tempo[1024];
+              char BIGSTK tempo[1024];
               tempo[0]='\0';
               
               sprintf(tempo,"%s.class",tab[tab[i].index1].name);
@@ -288,7 +288,7 @@ RESP_STRUCT readtable(htsmoduleStruct* str,
       strcpybuff(trans.name,"HTS_UNICODE");
     
     {
-      char buffer[1024]; 
+      char BIGSTK buffer[1024]; 
       char *p;
       
       p=&buffer[0];
