@@ -92,8 +92,10 @@ char* __cdecl htsshow_query(char* question);
 char* __cdecl htsshow_query2(char* question);
 char* __cdecl htsshow_query3(char* question);
 int   __cdecl htsshow_check(char* adr,char* fil,int status);
+int   __cdecl htsshow_check_mime(char* adr,char* fil,char* mime,int status);
 void  __cdecl htsshow_pause(char* lockfile);
 void  __cdecl htsshow_filesave(char* file);
+void  __cdecl htsshow_filesave2(char* adr, char* fil, char* save, int is_new, int is_modified, int not_updated);
 int   __cdecl htsshow_linkdetected(char* link);
 int   __cdecl htsshow_linkdetected2(char* link, char* start_tag);
 int   __cdecl htsshow_xfrstatus(lien_back* back);
