@@ -64,7 +64,7 @@ int hts_zunpack(char* filename,char* newfile) {
         if (fpout) {
           int nr;
           do {
-            char buff[1024];
+            char BIGSTK buff[1024];
             nr=gzread (gz, buff, 1024);
             if (nr>0) {
               size+=nr;
@@ -90,8 +90,8 @@ int hts_extract_meta(char* path) {
     if (unzGoToFirstFile(zFile) == Z_OK) {
       zip_fileinfo fi;
       unz_file_info ufi;
-      char filename[HTS_URLMAXSIZE * 4];
-      char comment[8192];
+      char BIGSTK filename[HTS_URLMAXSIZE * 4];
+      char BIGSTK comment[8192];
       int entries = 0;
       memset(comment, 0, sizeof(comment));       // for truncated reads
       memset(&fi, 0, sizeof(fi));
